/* **********************************************************
 * Copyright (C) 1998-2005 VMware, Inc.
 * All Rights Reserved
 * **********************************************************/


#ifndef VM_TOOLS_VERSION_H
#define VM_TOOLS_VERSION_H

#ifndef RC_INVOKED
#define INCLUDE_ALLOW_USERLEVEL
#define INCLUDE_ALLOW_MODULE
#define INCLUDE_ALLOW_VMKERNEL
#define INCLUDE_ALLOW_MONITOR
#define INCLUDE_ALLOW_VMNIXMOD
#define INCLUDE_ALLOW_VMCORE
#define INCLUDE_ALLOW_VMMEXT
#include "includeCheck.h"

#include "vm_basic_types.h"
#endif /* RC_INVOKED */


/*
 * VERSION_MAGIC: 0x1 build-034 (beta-1)
 *                0x2 build-049 (beta-2)
 *                0x3 build-066 (beta-3)
 *                0x4 build-084
 *                0x5 build-093 (pre-public beta)
 *                0x6 build-096 (new layout of cross page)
 */


/*
 * XXX
 * XXX Don't ever change this number unless you want to
 * XXX force an upgrade of the VMware tools
 */

#define VERSION_MAGIC      0x6

#ifndef RC_INVOKED

typedef uint32 ToolsVersion;

#endif /* RC_INVOKED */

#define STRINGER(MJR, MNR, BASE)     #MJR "." #MNR "." #BASE "\0"
#define TOOLS_VERSION_STRINGER(MJR, MNR, BASE)    STRINGER(MJR, MNR, BASE)

#define TOOLS_VERSION_CSV(MJR, MNR, BASE)  MJR, MNR, BASE

/*
 * Generate the CSV define from the base variant defines.
 * E.g #define DRIVER_VERSION_CSV   TOOLS_VERSION_TO_CSV(TOOLS_VERSION_WS60_FF)
 * Result is: DRIVER_VERSION_CSV set to 7,2,0
 */
#define TOOLS_VERSION_TO_CSV(BASE_VARIANT)     \
   TOOLS_VERSION_CSV(BASE_VARIANT##_V_MJR,BASE_VARIANT##_V_MNR,BASE_VARIANT##_V_BASE)

/*
 * Generate the dotted STRING define from the base variant defines.
 * E.g #define DRIVER_VERSION_STR   TOOLS_VERSION_TO_STR(TOOLS_VERSION_WS60_FF)
 * Result is: DRIVER_VERSION_STR set to "7.2.0"
 */
#define TOOLS_VERSION_TO_STR(BASE_VARIANT)     \
   TOOLS_VERSION_STRINGER(BASE_VARIANT##_V_MJR,BASE_VARIANT##_V_MNR,BASE_VARIANT##_V_BASE)

#define TOOLS_VERSION_UINT(MJR, MNR, BASE)    (((MJR) << 10) + ((MNR) << 5) + (BASE))

/*
 * Allocate 5 bits to each sub-version in the dotted tools version. This
 * should take care of us for any reasonable usage: 32 x 32 x 32.
 * This macro takes the base variant appended with _V suffix and 
 * constructs the version number defines for the version.
 * It then passes the version numbers into the UINT construct macro above.
 */
#define TOOLS_VERSION_TO_UINT(BASE_VARIANT_VER)   \
   TOOLS_VERSION_UINT(BASE_VARIANT_VER##_MJR,BASE_VARIANT_VER##_MNR,BASE_VARIANT_VER##_BASE) 

/*
 * Allocate 5 bits to each sub-version in the dotted tools version. This
 * should take care of us for any reasonable usage: 32 x 32 x 32.
 */
#define TOOLS_VERSION_DOTTED(v1, v2, v3) (((v1) << 10) + ((v2) << 5) + (v3))

/*
 * The different tools versions that could be installed. Tools newer than
 * those contained in the install package will have version > CURRENT
 */
/*
 * Legacy (pre-dotted) versions.
 *
 * Note: Do **NOT** change any of these values, they are used in some
 * legacy code and will break if changed.
 */
#define   TOOLS_VERSION_NONE         0   // indicates no tools
#define   TOOLS_VERSION_OLD          1   // indicates pre-versioned tools
#define   TOOLS_VERSION_WS30_FF      2
#define   TOOLS_VERSION_WS30_BETA2   3
#define   TOOLS_VERSION_WS30         4
#define   TOOLS_VERSION_WS31_BETA    5

/* Dotted versions */
#define   TOOLS_VERSION_WS31_RC1       TOOLS_VERSION_DOTTED(1, 0, 0)
#define   TOOLS_VERSION_WS32           TOOLS_VERSION_DOTTED(1, 0, 1)
#define   TOOLS_VERSION_ESX15_BETA     TOOLS_VERSION_DOTTED(2, 0, 0)
#define   TOOLS_VERSION_GSX20_BETA     TOOLS_VERSION_DOTTED(3, 0, 0)
#define   TOOLS_VERSION_WKS40_FF       TOOLS_VERSION_DOTTED(4, 0, 0)
#define   TOOLS_VERSION_WKS40_BETA1    TOOLS_VERSION_DOTTED(4, 0, 1)
#define   TOOLS_VERSION_WKS40_BETA2    TOOLS_VERSION_DOTTED(4, 0, 2)
#define   TOOLS_VERSION_WKS40_BETA3    TOOLS_VERSION_DOTTED(4, 0, 3)
#define   TOOLS_VERSION_WKS40_RELEASE  TOOLS_VERSION_DOTTED(4, 0, 4)
#define   TOOLS_VERSION_WKS401_RELEASE TOOLS_VERSION_DOTTED(4, 0, 5)
#define   TOOLS_VERSION_ESX20_BETA1    TOOLS_VERSION_DOTTED(5, 0, 1)
#define   TOOLS_VERSION_ESX20_BETA2    TOOLS_VERSION_DOTTED(5, 0, 2)
#define   TOOLS_VERSION_VPX_BETA1      TOOLS_VERSION_DOTTED(5, 0, 3)
#define   TOOLS_VERSION_ESX20_RELEASE  TOOLS_VERSION_DOTTED(5, 0, 4)
#define   TOOLS_VERSION_ESX20_PATCH1   TOOLS_VERSION_DOTTED(5, 0, 5)
#define   TOOLS_VERSION_ESX20_PATCH2   TOOLS_VERSION_DOTTED(5, 0, 6)
#define   TOOLS_VERSION_WKS41_BETA1    TOOLS_VERSION_DOTTED(5, 1, 0)
#define   TOOLS_VERSION_ESX21_RELEASE  TOOLS_VERSION_DOTTED(5, 1, 1)
#define   TOOLS_VERSION_ESX21_PATCH1   TOOLS_VERSION_DOTTED(5, 1, 2)
#define   TOOLS_VERSION_ESX21_PATCH2   TOOLS_VERSION_DOTTED(5, 1, 3)
#define   TOOLS_VERSION_WKS452_GSX31_B TOOLS_VERSION_DOTTED(5, 2, 0)
#define   TOOLS_VERSION_GSX31_REL      TOOLS_VERSION_DOTTED(5, 2, 1)
#define   TOOLS_VERSION_WKS452_REL     TOOLS_VERSION_DOTTED(5, 2, 2)
#define   TOOLS_VERSION_GSX32_BETA     TOOLS_VERSION_DOTTED(5, 2, 3)
#define   TOOLS_VERSION_WKS50_FF       TOOLS_VERSION_DOTTED(6, 0, 0)
#define   TOOLS_VERSION_ESX25_RELEASE  TOOLS_VERSION_DOTTED(6, 1, 0)
#define   TOOLS_VERSION_ESX25_PATCH1   TOOLS_VERSION_DOTTED(6, 1, 1)
#define   TOOLS_VERSION_ACE_RC2        TOOLS_VERSION_DOTTED(6, 2, 0)
#define   TOOLS_VERSION_ACE101_BETA    TOOLS_VERSION_DOTTED(6, 2, 1)
#define   TOOLS_VERSION_WS50_BETA2     TOOLS_VERSION_DOTTED(6, 3, 0)
#define   TOOLS_VERSION_WS50_RC1       TOOLS_VERSION_DOTTED(6, 4, 0)
#define   TOOLS_VERSION_ESX251_RC1     TOOLS_VERSION_DOTTED(6, 5, 0)
#define   TOOLS_VERSION_ESX251_PATCH1  TOOLS_VERSION_DOTTED(6, 5, 1)
#define   TOOLS_VERSION_WS50_RC2       TOOLS_VERSION_DOTTED(6, 6, 0)
#define   TOOLS_VERSION_WS50_RELEASE   TOOLS_VERSION_DOTTED(6, 7, 0)
#define   TOOLS_VERSION_ESX30_BETA1    TOOLS_VERSION_DOTTED(7, 0, 0)
#define   TOOLS_VERSION_ESX30_BETA2    TOOLS_VERSION_DOTTED(7, 0, 1)
#define   TOOLS_VERSION_ESX30_RC1      TOOLS_VERSION_DOTTED(7, 0, 2)
#define   TOOLS_VERSION_ESX30_RC2      TOOLS_VERSION_DOTTED(7, 0, 3)
#define   TOOLS_VERSION_ESX30_RELEASE  TOOLS_VERSION_DOTTED(7, 0, 4)
#define   TOOLS_VERSION_ESX301_RC1     TOOLS_VERSION_DOTTED(7, 1, 0)
#define   TOOLS_VERSION_ESX301_RELEASE TOOLS_VERSION_DOTTED(7, 1, 1)
#define   TOOLS_VERSION_ESX301_PATCH   TOOLS_VERSION_DOTTED(7, 1, 2)
#define   TOOLS_VERSION_ESX302_GA      TOOLS_VERSION_DOTTED(7, 1, 2)
#define   TOOLS_VERSION_ESX301_PATCH2  TOOLS_VERSION_DOTTED(7, 1, 4)
#define   TOOLS_VERSION_ESX302_PATCH   TOOLS_VERSION_DOTTED(7, 1, 5)
/*
 * Leave the gap up to 16 for further patch/update/maintenance on
 * ESX 3.0.1 or ESX 3.0.2. Make sure to follow this if you need a 
 * new version number.
 * Tools version beyond 7,1,10 should be reserved for further 
 * ESX 3.0.x patch/udpate/maintenance. 
 */ 
#ifndef RC_INVOKED
#define   TOOLS_VERSION_ESX303_GA	TOOLS_VERSION_TO_UINT(TOOLS_VERSION_ESX303_GA_V)
#endif /* RC_INVOKED */
#define   TOOLS_VERSION_ESX303_GA_V_MJR     7
#define   TOOLS_VERSION_ESX303_GA_V_MNR     1
#define   TOOLS_VERSION_ESX303_GA_V_BASE    10

#define   TOOLS_VERSION_CURRENT        TOOLS_VERSION_ESX303_GA
#define   TOOLS_VERSION_CURRENT_CSV    TOOLS_VERSION_TO_CSV(TOOLS_VERSION_ESX303_GA)



#endif /* VM_TOOLS_VERSION_H */
